
# Pgai library release notes

## 0.1.0 (2024-10-23)

This is the first release of the Python pgai library, including the Vectorizer 
worker. When you have [defined vectorizers](/docs/vectorizer.md#define-a-vectorizer) 
on a self-hosted Postgres installation, you [run the Vectorizer worker](/docs/vectorizer-worker.md) to 
asynchronously processes them.

### New features and improvements

- Added the Vectorizer worker feature


